@@ -399,7 +399,11 @@ def inspect_transfers(params):
     list_src_endpoints = class_transfer_broker_.get_list_src_endpoints()
     list_dst_endpoints = class_transfer_broker_.get_list_dst_endpoints()
     # Get FTS Optimizer events for a given {src, dst} pair and drop duplicates events
-    df_fts_optimizer_data = get_fts_optimizer_events(params.get('CMD', 'cmd'))
+    # Curl command to query in elastic search
+    if 'src_rcsite' in threading.current_thread().name: filename = params.get('QUERY PARAMETERS', 'filename_src_query')
+    else: filename = params.get('QUERY PARAMETERS', 'filename_dst_query')
+    cmd = 'curl -s -X POST "' + params.get('FTS PARAMETERS', 'url_fts_raw_queue') + '" -H "Authorization: Bearer ' + class_transfer_broker_.get_auth_token() + '" -H "Content-Type: application/json" --data-binary "@' + filename + '"'
+    df_fts_optimizer_data = get_fts_optimizer_events(cmd)
     if 'src_rcsite' in threading.current_thread().name: df_query = df_fts_optimizer_data.query(params.get('QUERY PARAMETERS', 'query_src_site'), engine = 'python').drop_duplicates(subset = ['source_se', 'dest_se'], keep = 'first').reset_index(drop = True)
     else: df_query = df_fts_optimizer_data.query(params.get('QUERY PARAMETERS', 'query_dst_site'), engine = 'python').drop_duplicates(subset = ['source_se', 'dest_se'], keep = 'first').reset_index(drop = True)
     # Get latest FTS Optimizer event (first row), i.e. the most recent event generated by FTS Optimizer. Note that the whole traffic is the sum of all the transfer involved in all endpoints for the given {srv, dst} pairs -> sum columns
@@ -576,6 +580,7 @@ def main():
     class_transfer_broker_.set_num_circuits(config['number_of_dynamic_circuits'])
     class_transfer_broker_.set_sense_uuid(config['sense_uuid'])
     class_transfer_broker_.set_sense_vlan(config['sense_vlan'])
+    class_transfer_broker_.set_auth_token(config['auth_token'])
     # Build threads
     transfers_tx = build_thread(params, 'src_rcsite')
     transfers_rx = build_thread(params, 'dst_rcsite')
